@@ -121,7 +121,6 @@
 #define BOTAN_HAS_AEAD_SIV 20131202
 #define BOTAN_HAS_AES 20131128
 #define BOTAN_HAS_AES_CRYSTALS_XOF 20230816
-#define BOTAN_HAS_AES_NI 20131128
 #define BOTAN_HAS_AES_VAES 20240803
 #define BOTAN_HAS_AES_VPERM 20190901
 #define BOTAN_HAS_ANSI_X919_MAC 20131128
@@ -217,7 +216,6 @@
 #define BOTAN_HAS_FRODOKEM_AES 20231103
 #define BOTAN_HAS_FRODOKEM_SHAKE 20231114
 #define BOTAN_HAS_GHASH 20201002
-#define BOTAN_HAS_GHASH_CLMUL_CPU 20201002
 #define BOTAN_HAS_GHASH_CLMUL_VPERM 20201002
 #define BOTAN_HAS_GMAC 20160207
 #define BOTAN_HAS_GOST_28147_89 20131128
@@ -307,7 +305,6 @@
 #define BOTAN_HAS_POLY1305 20141227
 #define BOTAN_HAS_POLY_DBL 20170927
 #define BOTAN_HAS_PQCRYSTALS 20240228
-#define BOTAN_HAS_PROCESSOR_RNG 20200508
 #define BOTAN_HAS_PSK_DB 20171119
 #define BOTAN_HAS_PSS 20250130
 #define BOTAN_HAS_PUBLIC_KEY_BLINDING 20250125
